roundtrip_plan

Function roundtrip_plan 

pub fn roundtrip_plan(input: &str)
Roundtrip a plan and verify that the output is the same as the input, after being parsed to a Substrait plan and then back to text.