pub fn roundtrip_plan_with_verbose(input: &str, verbose_input: &str)
Roundtrip a plan and verify that the output is the same as the input, after being parsed to a Substrait plan and then back to text.